<?xml version="1.0" ?> 
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<!--
  Style sheet for converting xmlp-issues.xml into a static HTML
  document
        January 28, 2002 (CBF)
          adapted from XML Protocol WG Issues List XSLT.
        November 6, 2001 (HH)
          Not using the initials thingy anymore.
        October 16, 2001 (HH)
          Added list of maintainer.
        October 3, 2001 (HH)
          Removed closed issues from the summary table.
        October 3, 2001 (HH)
          Added an explanation of the acronyms used.
        September 25, 2001 (HH)
          Added support for em.
	September 18, 2001 (HH)
	  Added a few spaces.
        September 6, 2001 (HH)
          Now referencing xmlp-comments.
        September 6, 2001 (HH)
          Changed order in the summary from alphabetical to:
          Active, Unassigned, Postponed, Closed
          Fixed order of locus to:
          Spec, AM
        August 24, 2001 (HH)
          Added template for <pre>, and removed the one for text()
          which was unnecessary.
        June 20, 2001 (HH)
          Added some colors to make the list clearer
        June 3, 2001 (DCF)
          Added subheading to show xmlp-issues.xml (up)date
        May 30, 2001 (DCF)
          Added support for topic and title fields
        May 24, 2001 (DCF)
          Added summary table, doctype and style statements
        May 23, 2001 (DCF)
          Added support for proposal tag, reworded table text
        May 16, 2001 (DCF)
          Added default sort by issue number
        May 14, 2001 (DCF)
          Initially created

  $Id: xmlp-issues-html.xsl,v 1.18 2001/11/06 10:53:18 hugo Exp $
-->

<xsl:strip-space elements="*"/>
<xsl:output
   method="html"
   encoding="iso-8859-1"
   omit-xml-declaration="yes"
   doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN"
   />

<xsl:template match="/">
  <html>
    <head>
      <title>OASIS ebXML Message Service TC Issues List</title>

      <style type="text/css">
         body {color: black; background: white;}
         .Closed { background-color: #888888; }
      </style>

    </head>
    <body>
    <table><tr><td width="5%" align="center" valign="middle">
    <a href="http://oasis-open.org/">
    <img src="http://oasis-open.org/images/oasis_logo.gif" alt="OASIS" 
    bgcolor="#3c1a57"
    height="46"
    width="131" border="0"/></a>
    </td><td width="95%">
    <a href="http://oasis-open.org/committees/ebxml-msg">OASIS ebXML Messaging TC</a>
    </td></tr></table>

    <h1>OASIS ebXML Messaging TC Issues List</h1>
    
    <h3>Last update: <xsl:value-of select="issues/@update"/></h3>
    
    <p>Issues regarding the <a href="./#drafts">documents produced by
    the OASIS ebXML Messaging TC</a> should be reported to <a
    href="mailto:ebxml-msg@lists.oasis-open.org">ebxml-msg@lists.oasis-open.org</a> (<a
    href="http://lists.oasis-open.org/archives/ebxml-msg/">public
    archives</a>).</p>

    <p>Comments on this list should be sent to the
    <a href="mailto:ebxml-msg@lists.oasis-open.org">ebxml-msg@lists.oasis-open.org</a>
    mailing
    list (<a
    href="http://lists.oasis-open.org/archives/ebxml-msg/">Archives</a>).</p>

	<p></p>

    <ul>
      <li><a href="#summaryList">Summary list of outstanding issues</a></li>
      <li><a href="#detailList">Detailed list of issues</a></li>
      <li><a href="#legend">Legend for detailed list</a></li>
    </ul>
     
    <xsl:apply-templates mode="summary" />
    <xsl:apply-templates mode="detail" />

    <hr/>

	<xsl:apply-templates select="issues/maintainer" />

    </body>
  </html> 
</xsl:template>

<xsl:template match="issues" mode="summary">
  <h2><a name="summaryList"></a>Summary List of Outstanding Issues</h2>
  <table border='1'>
      <tr>
        <th><a href="#id">id</a></th>
        <th><a href="#Status">Status</a></th>
        <th><a href="#Spec">Spec</a></th>
        <th><a href="#Topic">Topic</a></th>
        <th><a href="#Class">Class</a></th>
        <th><a href="#Section">Section</a></th>
        <th><a href="#Title">Title</a></th>
      </tr>
    <xsl:apply-templates select="issue[child::status!='Closed']"
	mode="summary">
      <xsl:sort select="status='Postponed'" />
      <xsl:sort select="status='Unassigned'" />
      <xsl:sort select="status='Active'" />
      <xsl:sort select="topic" order="descending"/>
      <xsl:sort select="priority" />
      <xsl:sort data-type="number" select="issue-num" />
    </xsl:apply-templates>
  </table>
</xsl:template>

<xsl:template match="issue" mode="summary">
      <tr>
        <td>
          <a href="#x{issue-num}">
            <xsl:value-of select="issue-num"/>
          </a>
        </td>
        <td><xsl:value-of select="status"/></td>
        <td><xsl:value-of select="locus"/></td>
        <td><xsl:value-of select="topic"/></td>
        <td><xsl:value-of select="priority"/></td>
        <td><xsl:value-of select="section"/></td>
        <td><xsl:value-of select="title"/></td>
      </tr>
</xsl:template>

<xsl:template match="issues" mode="detail">
   <h2><a name="detailList"></a>Detailed List of Issues</h2>
  <table border='1'>
      <tr>
        <th><a href="#id">id</a></th>
        <th><a href="#Spec">Spec</a></th>
        <th><a href="#Section">Section</a></th>
        <th><a href="#Topic">Topic</a></th>
        <th><a href="#Class">Class</a></th>
        <th><a href="#Status">Status</a></th>
        <th><a href="#Raised by">Raised By</a></th>
        <th><a href="#Owner">Owner</a></th>
      </tr>
    <xsl:apply-templates select="issue" mode="detail">
      <xsl:sort data-type="number" select="issue-num" />
    </xsl:apply-templates>
  </table>
  <h2><a name="legend">Table Legend</a></h2>
   <dl>
   <dt><a name="id">id</a></dt>
   <dd>Issue number</dd>
   <dt><a name="title">Title</a></dt>
   <dd>Short title/name of the issue</dd>
   <dt><a name="Spec">Spec</a></dt>
   <dd>Document referred to in issue (AM = Abstract Model, Spec = XMLP/SOAP Specification</dd>
   <dt><a name="Description">Description</a></dt>
   <dd>Short description of issue, possibly including link to origin of issue</dd>
   <dt><a name="Section">Section</a></dt>
   <dd>Reference to specification section that motivated this issue</dd>
   <dt><a name="Topic">Topic</a></dt>
   <dd>Rough topic categorisation, one of: env(elope), rpc, enc(oding), meta(issue), bind(ing), fault</dd>
   <dt><a name="Class">Class</a></dt>
   <dd>Design or Editorial</dd>
   <dt><a name="Status">Status</a></dt>
   <dd>One of: Unassigned, Active, Closed, Postponed</dd>
   <dt><a name="Proposal">Proposal</a></dt>
   <dd>Current proposal for resolution of issue, possibly including link to further text</dd>
   <dt><a name="Resolution">Resolution</a></dt>
   <dd>Short description of resolution, possibly including link to a more elaborate description</dd>
   <dt><a name="Raised">Raised by</a></dt>
   <dd>Person who raised the issue</dd>
   <dt><a name="Owner">Owner</a></dt>
   <dd>ebXML Messaging TC Member responsible for the issue</dd>
   </dl>
</xsl:template>

<xsl:template match="issue" mode="detail">
                <tbody class="{status}">
      <tr>
        <xsl:apply-templates select="issue-num" mode="detail" />
        <xsl:apply-templates select="locus" mode="detail" />
        <xsl:apply-templates select="section" mode="detail" />
        <xsl:apply-templates select="topic" mode="detail" />
        <xsl:apply-templates select="priority" mode="detail" />
        <xsl:apply-templates select="status" mode="detail" />
        <xsl:apply-templates select="originator" mode="detail" />
        <xsl:apply-templates select="responsible" mode="detail" />
      </tr>
      <tr>
        <xsl:apply-templates select="title" mode="detail" />
      </tr>
      <tr>
        <xsl:apply-templates select="description" mode="detail" />
      </tr>
      <tr>
        <xsl:apply-templates select="proposal" mode="detail" />
      </tr>
      <tr>
        <xsl:apply-templates select="resolution" mode="detail" />
      </tr>
                     </tbody>
</xsl:template>

<xsl:template match="issue-num" mode="detail">
  <td rowspan='5' valign='top'>
    <b><a name="x{.}"><xsl:value-of select="."/></a></b> 
  </td>
</xsl:template>

<xsl:template match="locus" mode="detail">
  <td>
    <xsl:apply-templates />
  </td>
</xsl:template>

<xsl:template match="section" mode="detail">
  <td>
    <xsl:apply-templates />
  </td>
</xsl:template>

<xsl:template match="topic" mode="detail">
  <td>
    <xsl:apply-templates />
  </td>
</xsl:template>

<xsl:template match="priority" mode="detail">
  <td>
    <xsl:apply-templates />
  </td>
</xsl:template>

<xsl:template match="status" mode="detail">
  <td>
    <xsl:apply-templates />
  </td>
</xsl:template>

<xsl:template match="originator" mode="detail">
  <td>
    <xsl:apply-templates />
  </td>
</xsl:template>

<xsl:template match="responsible" mode="detail">
  <td>
    <xsl:apply-templates />
  </td>
</xsl:template>

<xsl:template match="title" mode="detail">
  <td colspan='7'>
    <b>Title:</b>
    <xsl:text> </xsl:text>
    <xsl:apply-templates />
  </td>
</xsl:template>

<xsl:template match="description" mode="detail">
  <td colspan='7'>
    <b>Description:</b>
    <xsl:text> </xsl:text>
    <xsl:apply-templates />
  </td>
</xsl:template>

<xsl:template match="proposal" mode="detail">
  <td colspan='7'>
    <b>Proposal:</b>
    <xsl:text> </xsl:text>
    <xsl:apply-templates />
  </td>
</xsl:template>

<xsl:template match="resolution" mode="detail">
  <td colspan='7'>
    <b>Resolution:</b>
    <xsl:text> </xsl:text>
    <xsl:apply-templates />
  </td>
</xsl:template>

<!-- Sign the document -->

  <xsl:template match="maintainer">
    <address>
      <small>
	Maintained by <a href="{uri}"><xsl:value-of select="fullname"/>.</a>
      </small>
    </address>
  </xsl:template>

<!-- HTML like stuff -->

<xsl:template match="a[@href]">
    <a>
      <xsl:attribute name="href">
        <xsl:value-of select="@href"/>
      </xsl:attribute>
      <xsl:apply-templates />
    </a>
</xsl:template>

<xsl:template match="a[@name]">
    <a>
      <xsl:attribute name="name">
        <xsl:value-of select="@name"/>
      </xsl:attribute>
      <xsl:apply-templates />
    </a>
</xsl:template>

<xsl:template match="pre">
  <pre>
    <xsl:apply-templates />
  </pre>
</xsl:template>

<xsl:template match="p">
  <p>
    <xsl:apply-templates />
  </p>
</xsl:template>

<xsl:template match="em">
  <em>
    <xsl:apply-templates />
  </em>
</xsl:template>

<xsl:template match="ul">
  <ul>
    <xsl:for-each select="li">
      <li><xsl:apply-templates /></li>
    </xsl:for-each>
  </ul>
</xsl:template>

</xsl:stylesheet>
